@@ -9,6 +9,7 @@ import pkg_resources
 from damask_parse import (
     read_geom,
     read_table,
+    read_HDF5_file,
     write_load_case,
     write_geom,
     write_material_config,
@@ -30,7 +31,6 @@ from matflow_damask import (
     register_output_file,
     software_versions,
 )
-from matflow_damask.utils import get_HDF5_incremental_quantity
 
 
 @input_mapper(
@@ -147,82 +147,7 @@ def write_damask_material(path, homogenization_schemes, homogenization_labels,
 
 @output_mapper('volume_element_response', 'simulate_volume_element_loading', 'CP_FFT')
 def read_damask_hdf5_file(hdf5_path, incremental_data, operations=None):
-    """Operate on and extract data from an HDF5 file generated by a DAMASK run.
-
-    Parameters
-    ----------
-    hdf5_path : Path or str
-        Path to the HDF5 file.
-    incremental_data : list of dict
-        List of incremental data to extract from the HDF5 file. This is a list of dicts
-        with the following keys:
-            name: str
-                The name by which the quantity will be stored in the output dict.
-            path: str
-                The HDF5 "path" to the dataset.
-            transform: list of dict, optional
-                If specified this is a list of dicts, each with the following keys:
-                    sum_along_axes : int, optional
-                        If specified, take the sum the array along this axis.
-                    mean_along_axes: int, optional
-                        If specified, take the mean average of the array along this axis.
-    operations : list of dict, optional
-        List of methods to invoke on the DADF5 object. This is a list of dicts with the
-        following keys:
-            name : str
-                The name of the DADF5 method.
-            args : dict
-                Parameter names and their values to pass to the DADF5 method. This
-                assumes all DADF5 method parameters are of positional-or-keyword type.
-            opts : dict
-                Additional options.
-
-    Returns
-    -------
-    volume_element_response : dict
-        Dict with keys determined by the `incremental_data` list.
-
-    """
-
-    sim_data = DADF5(hdf5_path)
-
-    for op in operations or []:
-        func = getattr(sim_data, op['name'], None)
-        if not func:
-            raise AttributeError(f'The DADF5 object has no attribute: {op["name"]}.')
-        else:
-            func(**op['args'])
-
-        # Deal with specific options:
-        if op['opts'].get('add_Mises', {}):
-
-            if op["name"] == 'add_Cauchy':
-                label = f'sigma'
-
-            elif op["name"] == 'add_strain_tensor':
-                # Include defaults from `DADF5.add_strain_tensor`:
-                t = op['args'].get('t', 'U')
-                m = op['args'].get('m', 0)
-                F = op['args'].get('F', 'F')
-                label = f'epsilon_{t}^{m}({F})'
-
-            else:
-                msg = (f'Operation "{op["name"]}" is not compatible with option '
-                       f'"add_Mises".')
-                raise ValueError(msg)
-
-            sim_data.add_Mises(label)
-
-    volume_element_response = {}
-    for inc_dat_spec in incremental_data:
-        inc_dat = get_HDF5_incremental_quantity(
-            hdf5_path=hdf5_path,
-            dat_path=inc_dat_spec['path'],
-            transforms=inc_dat_spec.get('transforms'),
-        )
-        volume_element_response.update({inc_dat_spec['name']: inc_dat})
-
-    return volume_element_response
+    return read_HDF5_file(hdf5_path, incremental_data, operations=operations)
 
 
 @input_mapper('phase_label.txt', 'generate_volume_element', 'random_voronoi')
